/*******************************************************************************
				Neoinput
				========

		Copyright (C) 2010 Paul Kocialkowski

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#include "config.h"
#include "input.h"

/* Socket file descriptor */
int sock_fd;

/* Struct to store the server address */
struct sockaddr_in server_addr;

void server_connect(char *server_ip, int server_port)
{
	/* Start to open a socket */
	sock_fd=socket(AF_INET, SOCK_STREAM, 0);


	/* Check if the socket is ok */
	if(sock_fd == -1)
	{
		perror("Error in socket()");
		exit(1);
	}
	else
		printf("socket(): OK...\n");

	/* Server address family */
	server_addr.sin_family=AF_INET;

	/* Server port */
	server_addr.sin_port=htons(server_port);

	/* Server address */
	server_addr.sin_addr.s_addr=inet_addr(server_ip);

	/* Set the Rest of the struct to 0 */

	memset(&(server_addr.sin_zero), 0, 8);

	/* Connect and check if the connection is ok */ 
	if(connect(sock_fd, (struct sockaddr *) &server_addr, sizeof(struct sockaddr)) == -1)
	{
		perror("Error in connect()");
		exit(1);
	}
	else
		printf("connect(): OK...\n");
}

void server_disconnect(void)
{
	close(sock_fd);
}

void server_send(struct input_event_light data)
{
	if(!write(sock_fd, &data, sizeof(data)))
	{
		perror("Error in write()");
		exit(1);
	}
}

void server_send_input_type(int input_type)
{
	printf("Sending input type...\n");

	if(!write(sock_fd, &input_type, sizeof(input_type)))
	{
		perror("Error in write()");
		exit(1);
	}
}

void server_get_status(void)
{
	printf("Getting server status...\n");

	int status=STATUS_ERROR;

	if(!read(sock_fd, &status, sizeof(status)))
	{
		perror("Error in write()");
		exit(1);
	}

	if(status != STATUS_OK)
	{
		printf("Wrong status. Aborting.\n");
		exit(1);
	}
}
