/*******************************************************************************
				Neoinput
				========

		Copyright (C) 2010 Paul Kocialkowski

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#include <string.h>
#include <stdio.h>
#include <unistd.h>

#include <fcntl.h>
#include <poll.h>

#include <linux/input.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>

#include "client.h"
#include "input_read.h"
#include "input.h"
#include "config.h"

int input_touch;
int input_accel;
int input_button_aux;
int input_button_power;

void input_open_read(int input_type)
{
	switch(input_type)
	{
		case INPUT_TYPE_TOUCH :
		case INPUT_TYPE_TOUCH_ROTATE :
			input_touch=open(DEVICE_TOUCH, O_RDONLY);
			input_button_aux=open(DEVICE_BUTTON_AUX, O_RDONLY);
			input_button_power=open(DEVICE_BUTTON_POWER, O_RDONLY);
		break;
		case INPUT_TYPE_ACCEL :
			input_touch=open(DEVICE_TOUCH, O_RDONLY);
			input_accel=open(DEVICE_ACCEL, O_RDONLY);
		break;
	}

	if(input_touch < 0 || input_button_aux < 0 || input_button_power < 0)
	{
		printf("Error while opening input device\n");
		exit(1);
	}

}

void input_event_read(int input_type)
{
	struct input_event event;
	struct input_event_light event_light;
	struct pollfd poll_fd[3];
	int r, i;

	printf("Reading data...\n");

	switch(input_type)
	{
		case INPUT_TYPE_TOUCH :
		case INPUT_TYPE_TOUCH_ROTATE :
			poll_fd[0].fd=input_touch;
			poll_fd[1].fd=input_button_aux;
			poll_fd[2].fd=input_button_power;

			poll_fd[0].events = POLLIN | POLLPRI;
			poll_fd[1].events = POLLIN | POLLPRI;
			poll_fd[2].events = POLLIN | POLLPRI;

			while(1)
			{
				/* Poll the inputs */
				r=poll(poll_fd, (sizeof(poll_fd) / sizeof(struct pollfd)), POLL_TIMEOUT);

				if(r >= 0)
				{
					for(i=0 ; i < (sizeof(poll_fd) / sizeof(struct pollfd)) ; i++)
					{
						if((poll_fd[i].revents & POLLIN) || (poll_fd[i].revents & POLLPRI))
						{
							read(poll_fd[i].fd, &event, sizeof(struct input_event));

							event_light.type=event.type;
							event_light.code=event.code;
							event_light.value=event.value;

							server_send(event_light);
						}

					}
				}
				else
				{
					perror("Error in poll()");
					exit(1);
				}
			}
		break;
		case INPUT_TYPE_ACCEL :
			poll_fd[0].fd=input_touch;
			poll_fd[1].fd=input_accel;

			poll_fd[0].events = POLLIN | POLLPRI;
			poll_fd[1].events = POLLIN | POLLPRI;

			while(1)
			{
				/* Poll the inputs */
				r=poll(poll_fd, (sizeof(poll_fd) / sizeof(struct pollfd)), POLL_TIMEOUT);

				if(r >= 0)
				{
					for(i=0 ; i < (sizeof(poll_fd) / sizeof(struct pollfd)) ; i++)
					{
						if((poll_fd[i].revents & POLLIN) || (poll_fd[i].revents & POLLPRI))
						{
							read(poll_fd[i].fd, &event, sizeof(struct input_event));

							event_light.type=event.type;
							event_light.code=event.code;
							event_light.value=event.value;

							server_send(event_light);
						}

					}
				}
				else
				{
					perror("Error in poll()");
					exit(1);
				}
			}
		break;
	}
}

void input_close(void)
{
	if(input_touch)
		close(input_touch);
	if(input_accel)
		close(input_accel);
	if(input_button_aux)
		close(input_button_aux);
	if(input_button_power)
		close(input_button_power);
}
