/*******************************************************************************
				Neoinput
				========

		Copyright (C) 2010 Paul Kocialkowski

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "config.h"

#include "client.h"
#include "input_read.h"

void print_version(void)
{
	printf("%s_client %s, %s\n", SOFTWARE, VERSION, DESCRIPTION);
	printf("%s\n", COPYRIGHT);
}

void print_help(void)
{
	print_version();
	printf("\nUsage: %s_client [OPTION]... [TYPE]\n", SOFTWARE);
	printf("\nOptions:\n");
	printf("  --help        Shows this help message.\n");
	printf("  --version     Shows the program version.\n");
	printf("  -a [ADDRESS]  Specify the IP address to connect on.\n");
	printf("  -p [PORT]     Specify the port to connect on.\n");
	printf("\nTypes:\n");
	printf("touch           Use the touchscreen (and the buttons)\n");
	printf("touch-rotate    Use the 90deg rotated touchscreen (and the buttons)\n");
	printf("accel           Use the accelerometers (and the buttons) - not yet implented\n");
	printf("multimedia      Use the multimedia GUI - not yet implented\n");

}


int main(int argc, char **argv)
{
	int i, j;

	int server_port=0;
	char *server_ip=NULL;

	int input_type=INPUT_TYPE_ERROR;
	char append=0;

	/* Check args */

	for(i=1 ; i < argc ; i++)
	{
		if(argv[i][0] == '-')
		{
			if(argv[i][1] == '-')
			{
				if(strcmp(argv[i], "--help") == 0)
				{
					print_help();
					exit(0);
				}
				else if(strcmp(argv[i], "--version") == 0)
				{
					print_version();
					exit(0);
				}
				else
				{
					printf("Error: Unknown argument '%s'.\n", argv[i]);
					exit(1);
				}
			}
			else
			{
				for(j=1 ; j < strlen(argv[i]) ; j++)
				{
					if(append)
					{
						printf("Error: missing value for argument '%c'.\n", append);
						exit(1);
					}
					
					switch(argv[i][j])
					{
						case 'a':
							append='a';
						break;

						case 'p':
							append='p';
						break;

						default:
							printf("Error: Unknown argument '%c'.\n", argv[i][j]);
						break;
					}
				}
			}
		}
		else
		{
			if(append)
			{
				if(append == 'p' && server_port == 0)
					server_port=atoi(argv[i]);
				else if(append == 'a' && server_ip == NULL)
					server_ip=argv[i];
				else
				{
					printf("Error: Argument '%c' redifinition.\n", append);
					exit(1);
				}

				append=0;
			}
			else if(input_type == INPUT_TYPE_ERROR)
			{
				if(strcmp(argv[i], "touch") == 0)
					input_type=INPUT_TYPE_TOUCH;
				else if(strcmp(argv[i], "touch-rotate") == 0)
					input_type=INPUT_TYPE_TOUCH_ROTATE;
				else if(strcmp(argv[i], "accel") == 0)
					input_type=INPUT_TYPE_ACCEL;
				else if(strcmp(argv[i], "multimedia") == 0)
					input_type=INPUT_TYPE_MULTIMEDIA;
				else
				{
					printf("Error: Unknown argument '%s'.\n", argv[i]);				exit(1);
				}
			}
			else
			{
				printf("Error: Unknown argument '%s'.\n", argv[i]);				exit(1);
			}
		}
	}

	if(server_port == 0)
	{
		printf("No server port specified, using	: DEFAULT_PORT (%d).\n", DEFAULT_PORT);
		server_port=DEFAULT_PORT;
	}
	if(server_ip == NULL)
	{
		printf("No server ip specified, using	: DEFAULT_IP (%s).\n", DEFAULT_IP);
		server_ip=DEFAULT_IP;
	}
	if(input_type == INPUT_TYPE_ERROR)
	{
		printf("No input type specified, using	: INPUT_TYPE_TOUCH.\n");
		input_type=INPUT_TYPE_TOUCH;
	}


	/* Connect the server */
	server_connect(server_ip, server_port);

	/* Send the input type */
	server_send_input_type(input_type);

	/* Get the server response */
	server_get_status();

	/* Open the input device */
	if(input_type == INPUT_TYPE_TOUCH || input_type == INPUT_TYPE_TOUCH_ROTATE || input_type == INPUT_TYPE_ACCEL)
	{
		input_open_read(input_type);
	}

	/* Sinon, tu lance une belle interface !*/

	input_event_read(input_type);

	input_close();
	server_disconnect();
}
